#############################
Contributing to *AFQ-Insight*
#############################

*AFQ-Insight* is an open-source software project. This means that you are welcome
to use it (see `LICENSE
<https://github.com/richford/AFQ-Insight/blob/main/LICENSE>`_ for details).

It also means that we welcome contributions from developers outside of our
research collaboration and we will credit these contributions appropriately.

Detailed guidelines for contribution are available `here
<https://github.com/richford/AFQ-Insight/blob/main/.github/CONTRIBUTING.md>`_.
